@@ -2,7 +2,7 @@ from qq.application import Application
 from qq.context import ApplicationNotStartedError
 from qq.context import Context
 from qq.injector import ContextManagerInjector
-from qq.injector import InitializeInjectors
+from qq.injector import InjectApplication
 from qq.injector import Injector
 from qq.injector import SimpleInjector
 from qq.plugin import Plugin
