@@ -2,18 +2,16 @@ from celery import Celery
 
 from qq.application import Application
 from qq.plugins.settings import SettingsBasedPlugin
-from qq.plugins.settings import SettingsPlugin
 
 
 class CeleryPlugin(SettingsBasedPlugin):
-    DEFAULT_KEY = "celery"
+    key = "celery"
 
     def __init__(
         self,
         celeryapp: Celery,
-        settings_key: str = SettingsPlugin.DEFAULT_KEY,
     ):
-        super().__init__(settings_key)
+        super().__init__()
         self.celeryapp = celeryapp
 
     def start(self, application: Application):
